@@ -54,20 +54,19 @@ fortify.kmeans <- function(model, data=NULL, ...)
     return(data)
 }
 
-#' plot.kmeans
-#' 
-#' Plot the results from a k-means object
-#' 
-#' Plots the results of k-means with color-coding for the cluster membership.  If \code{data} is not provided, then just the center points are calculated.
-#' 
+#' @title plot.kmeans
+#' @description Plot the results from a k-means object
+#' @details Plots the results of k-means with color-coding for the cluster membership.  If \code{data} is not provided, then just the center points are calculated.
 #' @aliases plot.kmeans
-#' @export
+#' @method plot kmeans
 #' @export plot.kmeans
+#' @export
 #' @author Jared P. Lander
 #' @seealso kmeans fortify ggplot plot.kmeans
 #' @param x A \code{\link{kmeans}} object.
 #' @param data The data used to kit the \code{\link{kmeans}} object.
 #' @param class Character name of the "true" classes of the data.
+#' @param size Numeric size of points
 #' @param legend.position Character indicating where the legend should be placed.
 #' @param title Title for the plot.
 #' @param xlab Label for the x-axis.
@@ -80,22 +79,25 @@ fortify.kmeans <- function(model, data=NULL, ...)
 #' plot(k1)
 #' plot(k1, data=iris)
 #' 
-plot.kmeans <- function(x, data=NULL, class=NULL, legend.position=c("right", "bottom", "left", "top", "none"), 
-                        title="K-Means Results",
-                        xlab="Principal Component 1", ylab="Principal Component 2", ...)
+plot.kmeans <-
+    function(x, data=NULL, class=NULL, size=2, 
+             legend.position=c("right", "bottom", "left", "top", "none"), 
+             title="K-Means Results",
+             xlab="Principal Component 1", ylab="Principal Component 2", ...)
 {
-    # fortify the model and data so it is convenient to plot in ggplot
-    toPlot <- fortify(model=x, data=data)
+      # fortify the model and data so it is convenient to plot in ggplot
+      toPlot <- fortify(model=x, data=data)
     
-    # get the legend position
-    legend.position <- match.arg(legend.position)
+      # get the legend position
+      legend.position <- match.arg(legend.position)
     
-    # convert class to factor just in case it is not already
-    if(!is.null(class)) toPlot[, class] <- factor(toPlot[, class])
-    
-    ggplot(toPlot, aes_string(x=".x", y=".y", colour=".Cluster")) + 
-        geom_point(aes_string(shape=class)) + 
-        scale_color_discrete("Cluster") +
-        theme(legend.position=legend.position) +
-        labs(title=title, x=xlab, y=ylab)
+      # convert class to factor just in case it is not already
+      if(!is.null(class)) toPlot[, class] <- factor(toPlot[, class])
+      
+      ggplot(toPlot, aes_string(x='.x', y='.y', colour='.Cluster')) + 
+          geom_point(aes_string(shape=class), size=size) + 
+          scale_color_discrete("Cluster") +
+          theme(legend.position=legend.position) +
+          labs(title=title, x=xlab, y=ylab)
 }
+
